from setuptools import setup

setup(name='python_oop',
      version='0.2',
      description='Gaussian distributions',
      packages=['python_oop'],
      author = 'Chetan Bhangale',
      author_email = 'cbhangale4@gmail.com',
      zip_safe=False)
